#ifndef NT2_INCLUDE_CONSTANTS_FALSE_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_FALSE_HPP_INCLUDED

#include <nt2/constant/include/constants/false.hpp>

#endif
